package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@$!`0````````````,`*``!````Y1<``#0```#PL0````0`!30`(``)
M`"@`'``;``$``'"(H```B*```(B@```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!0````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````"4H```E*````4```````$`
M`0```)"M``"0K0$`D*T!`,P"``#D$@``!@```````0`"````G*T``)RM`0"<
MK0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DD*T`
M`)"M`0"0K0$`<`(``'`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````$`````$```!'3E4```````,````"``````````0````4
M`````P```$=.50#3&RT;20>=YKQK]SXW%'^/,:UO,A$```!1````"`````@`
M```!D!`$)4`$@"B```&@AE"`@`$```LH!(TXH!)%B@0("%$```!2````5@``
M`%L```!<````8P```&0```!E````9P```&@`````````:@```&L```!L````
M;@```````````````:\TZ&[%WQ_JT^\.SMY'+6M_FGPNQ9NV=E0\E"#_Y`ZX
MC?$.U634?-EQ6!SB1\8!K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>O
MS&9"1=7LB0=PTPT4XI[:S>.>,V+;[0TZEPM_J9R;OMI7&^&G`@JCX/M)````
M``````````````````````#\$@````````,`"P``````F*T!```````#`!0`
MN`(`````````````$@```&8#`````````````!(````Z`P`````````````B
M````?P,`````````````$0```!P$`````````````!(````1````````````
M```@````*0(`````````````$@````P#`````````````!(```!7`P``````
M```````2````)0$`````````````$@```)T#`````````````!$```#(````
M```````````2````TP(`````````````$@```)<!`````````````!(```"_
M`@`````````````2````F```````````````$@```"`!`````````````!(`
M``#:`@`````````````2````:0(`````````````$@```#@"````````````
M`!(```!Z`@`````````````2````AP(`````````````$@```!4!````````
M`````!$```![`0`````````````2````]P``````````````$0```$D!````
M`````````!(````3`P`````````````2````!0,`````````````$0```!P#
M`````````````!(```#6```````````````2````Q0$`````````````$@``
M`"$"`````````````!(```"R`0`````````````2````\P(`````````````
M$@````D"`````````````!(```"^`0`````````````2````;0,`````````
M````$@```%<!`````````````!(````M```````````````@````G`(`````
M````````$@```$H"`````````````!(```"J`@`````````````2````T`$`
M````````````$0```'@``````````````!(````I`P`````````````2````
MIP``````````````$@```!`"`````````````!(```!)`P`````````````2
M````LP``````````````$@```%<"`````````````!(```!P`0``````````
M```2````@0(`````````````$@```+$"`````````````!(````V`0``````
M```````2````:@``````````````$@```"H!`````````````!(```"G`0``
M```````````2````Q0(`````````````$@````0!`````````````!(```"5
M`@`````````````2````7P,`````````````$@```*,"`````````````!(`
M``")`0`````````````2````AP``````````````$@```(`#````````````
M`"$````\```````````````@````,`,`````````````$@```.@`````````
M`````!(```!G`0`````````````2````4```````````````(````($#````
M`````````!$```#[`@`````````````2````3P(`````````````$@```(\"
M`````````````!(````#`@`````````````2````Z`(`````````````$@``
M`&`"`````````````!(```#O`0`````````````2````T0,``'3``0``````
M$``8`"4$```=7P``4````!(`#0#S`P``S%\````````2``X`2@0``'%4``#X
M!P``$@`-`'H#```I%@``O`$``!(`#0#Y`P``$4\```0````2``T`P@,``%RP
M`0``````$``8`+@$```53P``M`$``!(`#0"R!```_!(````````2``L`Y00`
M`&E<``"T`@``$@`-`+8#``!<L`$``````!``&``Q!```R5```!8````2``T`
M9`0``-1?```$````$0`/`.0#``!TP`$``````!``&`#<`P``=,`!```````0
M`!@`L`0``/5-```X````$@`-`,4$``"94P``V````!(`#0#7!```*5,``&``
M```2``T`5P0```"P`0``````$``7`#X$``#A4```K````!(`#0"O`P``7+`!
M```````0`!<`F00``%BP`0`$````$0`7`.D#``#)7P```@```!(`#0")!```
MC5\``#P````2``T`700``.47````````$@`-`%D$````L`$``````"``%P`*
M!```B5,``!`````2``T`T`,``'3``0``````$``8`',$``!Y3@``F````!(`
M#0"C!```C5$``)P!```2``T``&QI8G!E<FPN<V\N-2XR-`!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R
M0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E
M<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T
M<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V
M7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O
M7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S
M=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A
M<`!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!O
M<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB8RYS;RXV
M`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U<`!C;&]S
M961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B
M;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L
M:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB
M8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L9"UL:6YU>"UA<FUH9BYS;RXS`%]?
M<W1A8VM?8VAK7V=U87)D`%]E9&%T80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R
M=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`7V5N9`!?7VQI8F-?8W-U7V9I;FD`
M<&%R7V-U<G)E;G1?97AE8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!P87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP
M9&ER`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!P87)?:6YI=%]E
M;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT````
M```````"``(``@`"``(````#``(``@`"``0````"`````@```````@`"``(`
M`@`"`````````````@`"``(```````,````"``,``@`"```````"``(``@``
M`````@````,``@````(````"``(````````````"`````@`"``(```````(`
M```"``````````(``@`"``(``P`"``(``P`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
MB0,``!`````@````%&EI#0``!`#[!`````````$``0#?`0``$````"`````4
M:6D-```#`/L$`````````0`!`"X"```0`````````!1I:0T```(`^P0`````
M``"0K0$`%P```)2M`0`7````N*\!`!<```#<KP$`%P```.2O`0`7````[*\!
M`!<````$L`$`%P````RP`0`7````$+`!`!<````4L`$`%P```!BP`0`7````
M'+`!`!<````@L`$`%P```"BP`0`7````++`!`!<````TL`$`%P```#BP`0`7
M````/+`!`!<```!`L`$`%P```$2P`0`7````3+`!`!<```!0L`$`%P```%BP
M`0`7````O*\!`!4%``#`KP$`%0@``,2O`0`5#0``R*\!`!40``#,KP$`%1D`
M`-"O`0`5&P``U*\!`!4>``#8KP$`%2D``."O`0`5+0``Z*\!`!4X``#PKP$`
M%4(``/2O`0`51```^*\!`!5(``#\KP$`%4D``+BN`0`6`P``O*X!`!8$``#`
MK@$`%@4``,2N`0`6!P``R*X!`!8)``#,K@$`%@H``-"N`0`6"P``U*X!`!8,
M``#8K@$`%@X``-RN`0`6#P``X*X!`!81``#DK@$`%A(``.BN`0`6$P``[*X!
M`!84``#PK@$`%A4``/2N`0`6%@``^*X!`!87``#\K@$`%A@```"O`0`6&@``
M!*\!`!8<```(KP$`%AT```RO`0`6'P``$*\!`!8@```4KP$`%B$``!BO`0`6
M(@``'*\!`!8C```@KP$`%B0``"2O`0`6)0``**\!`!8F```LKP$`%B<``#"O
M`0`6*```-*\!`!8I```XKP$`%BH``#RO`0`6*P``0*\!`!8L``!$KP$`%BX`
M`$BO`0`6+P``3*\!`!8P``!0KP$`%C$``%2O`0`6,@``6*\!`!8S``!<KP$`
M%C0``&"O`0`6-0``9*\!`!8V``!HKP$`%C<``&RO`0`6.0``<*\!`!8Z``!T
MKP$`%CL``'BO`0`6/```?*\!`!8]``"`KP$`%CX``(2O`0`6/P``B*\!`!9`
M``",KP$`%D$``)"O`0`610``E*\!`!9&``"8KP$`%D<``)RO`0`62@``H*\!
M`!9+``"DKP$`%DP``*BO`0`630``K*\!`!9.``"PKP$`%D\``+2O`0`64```
M"$`MZ4D!`.L(@+WH!.`MY03@G^4.X(_@"/"^Y92;`0``QH_B&<J,XI3[O.4`
MQH_B&<J,XHS[O.4`QH_B&<J,XH3[O.4`QH_B&<J,XGS[O.4`QH_B&<J,XG3[
MO.4`QH_B&<J,XFS[O.4`QH_B&<J,XF3[O.4`QH_B&<J,XES[O.4`QH_B&<J,
MXE3[O.4`QH_B&<J,XDS[O.4`QH_B&<J,XD3[O.4`QH_B&<J,XCS[O.4`QH_B
M&<J,XC3[O.4`QH_B&<J,XBS[O.4`QH_B&<J,XB3[O.5X1\!&`,:/XAG*C.(8
M^[SE`,:/XAG*C.(0^[SE`,:/XAG*C.((^[SE`,:/XAG*C.(`^[SE`,:/XAG*
MC.+X^KSE`,:/XAG*C.+P^KSE`,:/XAG*C.+H^KSE`,:/XAG*C.+@^KSE`,:/
MXAG*C.+8^KSE`,:/XAG*C.+0^KSE`,:/XAG*C.+(^KSE`,:/XAG*C.+`^KSE
M`,:/XAG*C.*X^KSE`,:/XAG*C.*P^KSE`,:/XAG*C.*H^KSE`,:/XAG*C.*@
M^KSE`,:/XAG*C.*8^KSE`,:/XAG*C.*0^KSE`,:/XAG*C.*(^KSE`,:/XAG*
MC.*`^KSE`,:/XAG*C.)X^KSE`,:/XAG*C.)P^KSE`,:/XAG*C.)H^KSE`,:/
MXAG*C.)@^KSE`,:/XAG*C.)8^KSE`,:/XAG*C.)0^KSE>$?`1@#&C^(9RHSB
M1/J\Y7A'P$8`QH_B&<J,XCCZO.4`QH_B&<J,XC#ZO.4`QH_B&<J,XBCZO.4`
MQH_B&<J,XB#ZO.4`QH_B&<J,XACZO.4`QH_B&<J,XA#ZO.4`QH_B&<J,X@CZ
MO.4`QH_B&<J,X@#ZO.4`QH_B&<J,XOCYO.4`QH_B&<J,XO#YO.4`QH_B&<J,
MXNCYO.4`QH_B&<J,XN#YO.4`QH_B&<J,XMCYO.4`QH_B&<J,XM#YO.4`QH_B
M&<J,XLCYO.4`QH_B&<J,XL#YO.4`QH_B&<J,XKCYO.4`QH_B&<J,XK#YO.4`
MQH_B&<J,XJCYO.4`QH_B&<J,XJ#YO.4`QH_B&<J,XICYO.4`QH_B&<J,XI#Y
MO.7PM8FP6DQ;2WQ$!9`$D06H`Y($J>98`ZHS:`>3__<^[U5*5DNB6.!8$48$
M\(O\5$OC6!]X`"]MT%)+Y5@H:/_WVN^0^`XT`D8H:$/P`@."^`XT__?0[P6;
M!3.S\8!/D/@.)$+P`0*`^`XD;=*8`/_WVNY%2P2=3_`$#GM$0TI$22]H>D0<
M:'E$0DM[1,/X!.!"8`6:P6`!*IA@!V#(ORL=A&#$OP7K@@4`\0P!!=U3^`1+
MG4)!^`1/^=$W3P+Q@$$`)`,Q?T0`E$#X(4`#1CUI`S(R22A&>43_]RSO!$9(
MLR]-!J]]1"AI__=R[BU(.49X1`/P1?D0LRM+>T08:?_W0N[_]PSO!YHS:"!&
MFD(JT0FP\+W_]WKN)$IZ1!!A(+/_]RKN%TOE6"AH__=D[X#X?7:#YSAI__<T
M[P1&T.?H:$"Q!/#7^]?G&4L:2.%8>$3_]\+N&$@Y1GA$`_`1^>A@`"C)T.WG
M__<:[@$@__>*[GB8`0`8`0``/`$``$0!```D`0``(`$``+*9`0!F3```9DP`
M`*J9`0!PF0$`*S<``%"9`0"P20``.ID!`!J9`0`T`0``?DH``.1(``!/\``+
M3_``#@*\:D8$M`&TW_@DH`BCFD3?^"#`6O@,P$WX!,T&2UKX`S`&2%KX``#_
M]S+N__?H[I"6`0`,`0``.`$``$`!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_
M+P$2___J<)8!`"P!```'2PA(>T0(2GA$`S,;&GI$!BL#V05+TU@#L1A'<$<`
MOP28`0``F`$`2I8!`!0!```(20E(>40)2WA$"1I[1(D0`>O1<4D0`]`%2IM8
M`[$81W!'`+_4EP$`T)<!`!R6`0!,`0``"+4*2PI*>T1Z1!MX:[D)2]-8([$(
M2WM$&&C_]S+M__>]_P9+`2)[1!IP"+V>EP$`[)4!`!`!```VEP$`?I<!``=(
M"+5X1`)H!DM[1!*YO>@(0+OG!$J;6``K^-"81_;GG)0!`*J5`0!(`0``W_CD
M+M_XY#XMZ?!/>D2M]3]]`/$X!1RL`/%X#@"4`"8:D--8S>D&B1N3&VB]DVAH
M"#4#EA`T!98#"@*3`PX$D]WI`B,!!MWI!(D`(P+T?T)5^`A\2.H""$_J`"I)
MZ@,)=45"1@KT?P!"Z@$"1/@,;$M&/[I/\``!0NH``D/J`0-$^!!\1.D"(]'1
M#?%H#@WU&GQT1O[I`@'4Z1QGU.D2(]3I!D5R0'M`8D!K0$)`2T"0&.9%3^K2
M>$CJ0PA/\``#0.H(`L[I("/CT1J8`"4`F2]&T.D`--'I`(FC1@`D)D;-Z09G
M7D::1G4!!D;0Z0(!1>K:9<WI"*L/]MQ<W.D`O"I&S>D0`3!&UND$9QOK"`M,
MZPD,V$;-Z01G!D;0Z08!X4;6Z0AGW>D$O,WI"@%01LWI%&=$`=WI"F<B0]WI
M%$6+Z@8+C.H'#!3K"`1>1MWI$*M%ZPD%H$9G1ACK`@A41@3J!@2I1EU&)D8%
MZ@<%W>D*-$GQ``DO1EU&<T"M!P>5?$`>1@>;&.L&`E5&)T9#ZIH#!Y-)ZP<#
M5$:H"$#JBW";1J,'`)P&DQ=&3_``"$_P``G-Z0)XID:21M3I`D7=Z08C2T;=
MZ0*)3_``#,WI!D4"0\WI#"-$1MWI!(GF#MWI`D6(Z@((B>H#"0_V[$/3Z0`C
M1NI%%MWI!D6D&%U!(D8K1MWI"$4$Z@@$!>H)!:!&`IRI1F`!W>D*13!#I!A=
M0<WI!D7=Z00TW>D&9X/J"`.$Z@D$W>D(B?889T'-Z09G1T:\"-WI!F=$ZHET
M-AA`1D_J@')'\0`'(D/>Z01%"NH""LWI#F<31MWI#HG-Z19%`"4L1@OJ!0O-
MZ1(T3_``"=WI%C1/ZDD7S>D&JT?JV&</]D1+V^D`JT_J2!9/ZMEA`"`:ZP,*
MW>D,(TOK!`O=Z01%%.L*!$7K"P7=Z0*K(NH*"B/J"PM21EM&1^H&"D'J!PO=
MZ09GS>D6J]WI`JL60Z091^H#!WU!448F1HP(%ID6ZP$*W>D"9T7Q``O-Z1:K
M3_``"\WI`JM$ZH=TL@<B0]WI`D7>Z09G`"&31LWI!@%K`0>3#_:P,]/I`"/@
M#D#J11"2&7M!%D8?1MWI#B/-Z0Z\`NH+`@/J#`.21@>:FT9"ZM1C!Y/=Z0PC
M9`$&E)(9W>D&17M!%D8$0Q]&W>D2(P`@(NH(`B/J"0-*Z@(*2^H#"Q;K"@9/
MZHES1^L+!Q;K!`M'\0`,0^J8`T_JB')>1F=&3_``#-A&&D/-Z1AG8T;>Z0AG
M3_``"0_V'#S<Z0"\3^I)%<WI#"-%ZMAE&^L&"T_J2!1,ZP<,3^K985Y&W>D6
MJPKJ`@H+Z@,+W>D2(Y(9W>D"9T/K#`/-Z08CW>D.(T_P``PBZ@8&(^H'!TKJ
M!@I+Z@<+W>D&9Q;K"@9%Z@0*1^L+!T'J!0O-Z0:KW>D"JU%&C`@&F1;K`0I/
M\``!1_$`"]WI`F?-Z1:K3_``"\WI`JM$ZH=TL@<B0]WI`D7-Z08!WND*9Y-&
M:P$'DP_V:"/3Z0`CX`[-Z1*\0.I%$)(9>T$61A]&W>D8(P+J"P(#Z@P#DD8'
MFIM&0NK48P>3W>D.(V0!!I3<1I(9>T$61A]&W>D,(]WI!D4BZ@@"(^H)`TKJ
M`@M,Z@,,%NL+!D3J``1'ZPP'3^J)<Q;K!`M#ZI@#1_$`#$_JB'+-Z1B\3_``
M#-A&WND,9QI#8T8/]MP<W.D`O$_P``G-Z0XC3^I)%1OK!@M%ZMAE3.L'#$_J
M2!1>1MWI%JM/ZMEA`"`*Z@(*"^H#"]WI#".2&=WI`F=#ZPP#S>D&(]WI$B-/
M\``,(NH&!B/J!P=*Z@8*2^H'"]WI!F<6ZPH&1>H$"D?K"P=!Z@4+S>D&J]WI
M`JM11HP(!ID6ZP$*3_```4?Q``O=Z0)GS>D6JT_P``O-Z0*K1.J'=+('(D/=
MZ0)%S>D&`=[I#F>31FL!!Y,/]B`3T^D`(^`.S>D,O$#J11"2&7M!%D8?1MWI
M&","Z@L"`^H,`Y)&!YJ;1D+JU&,'D]WI$B-D`0:4W$:2&=WI!D5[019&!$,?
M1MWI#B,`("+J"`(CZ@D#2NH""TSJ`PP6ZPL&3^J)<T?K#`<6ZP0+1_$`#$/J
MF`-/ZHAR7D9G1D_P``S81AI#S>D89V-&WND09T_P``D/]HP,W.D`O$_J217-
MZ1(C1>K891OK!@M/ZD@43.L'#$_JV6%>1MWI%JL*Z@(*"^H#"]WI#B.2&=WI
M`F=#ZPP#S>D&(]WI#"-/\``,(NH&!B/J!P=*Z@8*2^H'"]WI!F<6ZPH&1>H$
M"D?K"P=!Z@4+S>D&J]WI`JM11HP(!ID6ZP$*3_```4?Q``O=Z0)GS>D6JT_P
M``O-Z0*K1.J'=+('(D/=Z0)%S>D&`=[I$F>31FL!!Y,/\MAST^D`(^`.S>D.
MO$#J11"2&7M!%D8?1MWI&","Z@L"`^H,`Y)&!YJ;1D+JU&,'D]WI#"-D`0:4
MW$:2&=WI!D5[019&!$,?1MWI$B,`("+J"`(CZ@D#2NH""TSJ`PP6ZPL&3^J)
M<T?K#`<6ZP0+1_$`#$/JF`/-Z1B\3^J(<D_P``S81M[I%&<:0V-&#_)(?-SI
M`+S-Z0PC3_``"1OK!@M/ZDD53.L'#$7JV&5>1MWI%JM/ZD@43^K980KJ`@H+
MZ@,+W>D2(Y(9W>D"9T/K#`/-Z08CW>D.(T_P``PBZ@8&(^H'!TKJ!@I+Z@<+
MW>D&9Q;K"@9%Z@0*1^L+!T'J!0O-Z0:KW>D"JU%&C`@&F1;K`0I/\``!1_$`
M"]WI`F?-Z1:K3_``"\WI`JM$ZH=TL@<B0]WI`D7-Z08!WND69Y-&:P$'DP_R
MD&/3Z0`CX`[-Z1*\0.I%$)(9>T$61A]&W>D8(P+J"P(#Z@P#DD8'FIM&0NK4
M8P>3W>D.(V0!!I3<1I(9W>D&17M!%D8$0Q]&W>D,(P`@(NH(`B/J"0-*Z@(+
M3.H##!;K"P9/ZHES1^L,!Q;K!`M'\0`,0^J8`\WI&+Q/ZHAR3_``#-A&WND8
M9QI#8T8/\@1LW.D`O,WI#B-/\``)&^L&"T_J215,ZP<,1>K895Y&W>D6JT_J
M2!1/ZMEA"NH""@OJ`PO=Z0PCDAG=Z0)G0^L,`\WI!B/=Z1(C3_``#"+J!@8C
MZ@<'2NH&"DOJ!PO=Z09G%NL*!D7J!`I'ZPL'0>H%"\WI!JO=Z0*K44:,"`:9
M%NL!"D_P``%'\0`+W>D"9\WI#*M/\``+S>D"JT3JAW2R!R)#WND:9]WI`D7-
MZ08!DT;-Z1:\:P$'DP_R2%/3Z0`CX`Y`ZD40DAE[019&'T;=Z1@C`NH+`@/J
M#`.21@>:FT9"ZM1C!Y/=Z1(C9`$&E-Q&DAG=Z09%>T$61@1#'T;=Z0XC(NH(
M`B/J"0-*Z@(+3.H##!;K"P9/ZHES1^L,!Q;K!`M'\0`,0^J8`T_JB')>1F=&
M3_``#-A&&D/-Z09G8T;>Z1QG3_``"0_RN$S<Z0"\3^I)%<WI$B-%ZMAE&^L&
M"T_J2!1,ZP<,3^K985Y&W>D,JPKJ`@H+Z@,+W>D.(Y(9W>D"9T/K#`/-Z0PC
MW>D6(R+J!@8CZ@<'2NH&"DOJ!PO=Z0QG`",6ZPH&1>H$"D?K"P=!Z@4+S>D,
MJ]WI`JM11HP(#)D6ZP$*3_```4?Q``O=Z0)GS>D.JT_P``M/ZDL51.J'=+('
M(D/>Z1YG1>K:94_J2A001@`BS>D"(T_JVF,"D_^CT^D`(\WI#`&2&7M!W>D,
M9Q!&&4;=Z08C`I4R0#M`%D8?1MWI%B.`&%E!W>D2(R+J"`(CZ@D#%D,?0S)&
M3^K;9@.6AA@[1D'K`P?=Z0(!`",=1@`B($-/ZHES%$9#ZI@#S>D"14_JB')/
MZI@$3^J9`0*43_``"#083_``"0*31_$`!4M&WND@9\WI%D5%1@_R;#G9Z0")
M`Y'=Z0(!&.L&"$GK!PG-Z0)%$$-&1D]&W>D.B0)&`"$`(,WI!@%I`>`.!Y$(
MZ@((W>D"10GJ`PG-Z0XC!YI`ZD400NK48P>3W>D2(V0!!I22&=WI!D5[019&
M!$,?1MWI#",`("+J"@(CZ@L#2.H""$GJ`PD6ZP@&3^J+<T?K"0<6ZP0(1_$`
M"4/JF@/-Z1B)3^J*<D_P``G"1M[I(F<:0TM&#_+$*=GI`(G-Z1(C3_``"QCK
M!@A/ZDL52>L'"47JVF5&1D_J2A1/1MWI%HE/ZMMA".H""`GJ`PG=Z0PCDAE[
M0=WI`F?-Z08CW>D.(R+J!@8CZ@<'2.H&"$GJ!PG=Z09G%NL(!D7J!`A'ZPD'
M0>H%"<WI!HG=Z0*)04:,"`:9%NL!"$_P``%'\0`)W>D"9\WI%HG-Z0(!`"%$
MZH=TL@='1D_P``C-Z09X(D/=Z09%B4;>Z21GD$;-Z0R)#?6X?FL!`Y.`H]/I
M`"/@#JE&0.I%$)(9>T$61A]&W>D8(P+J"`(+0,WI!B.@1@.:3^J;`4+JU&,#
MD]WI#B-D`0*4DAG=Z09%>T'-Z0:)%D;=Z0*)'T;=Z1(C2.H`""+J"@(CZ@L#
M%$,=0S893^J*=&]!%NL(`D?Q``-/ZHMU1>J:!1=&F$8`FT3J!0M%Z@$,S>D.
M>``DD$8`)2!&*4;-Z0(!3^K880*17D;=Z18!9T;3Z28C3_``"@_R4!S<Z0"\
M,$#-Z1AG`"<Y0,WI%F?=Z1)G&^L""TSK`PS=Z08C%NL+!D_J2A5'ZPP'W>D,
MO-%&1>K892SJ`P,"E0M#*^H"`D_JVF$#D=WI`JM/ZD@4`D,`(+882NH$"E]!
M%NL*`MWI!JM'\0`#%D8?1@`C6D;-Z1)GE0=21I0'6D9%ZIH%D0@`FD7J`0M$
MZ@4*W>D811]&S>D&J]+I*".%Z@L%#_*T#-SI`+R$Z@H$`"'-Z0(!&^L""R!&
M3.L##'D!7$;=Z0ZK`Y$I1HKJ``IE1HOJ`0O-Z0ZKW>D,O'$!`YOR#@*1&^L$
M"PZ93.L%#$/JUF-/ZHEU`Y,;ZP$*1>J8!=WI`@%/ZHAT3^J9`43J!0A"ZD<2
M1>H!"4#J`@!,\0`+&NL`"DE&0$;=Z0:)2_$`"P";`"2(Z@`(S>D8JT_P``L`
M)=/I*B/-Z0)%#N``OZ_S`("9>8):`````*'KV6X`````?)4!`!@!``!/ZDL4
M`Y1$1@_VE&G9Z0")O0?-Z0P!1>J6!1CK`@A/ZMIB2>L#"0.;0$9"ZDL224;=
MZ1*)0^K:8P.3B.H$"$1&W>D6B1CK``A)ZP$)&.L$`$_J2A$"D4GQ``&`1K0'
M`)Z)1MWI`@&Y"!!#1>H!!QCK``A)\0`)S>D2B=;I+"-$Z@4&.4;=Z0Q%,$;-
MZ0X!#_808='I``%T0$_P``E/ZD@6@!A/ZDD764'=Z1@CS>D6`4?JV&<&F6)`
M`I=/ZMEC%$8#DPI&W>D6`4_JBW6`&$7JF@5!\0`!`AE!\0`#S>D&(]WI`B-/
MZHIT3^J;`43J!0HR0]WI!F=%Z@$+5$:V&$?Q``==1C)&W>D.JSM&S>D6(P":
M`",?1@_VB%S<Z0"\>0&*Z@0*TNDN(\WI!D541AOK`@M/ZHEU3.L##$'JUF/=
MZ1(21>J8!0.3\@YA0$+J1Q(`FPQ&#)D;ZP$`3/$``0`93^J(=(M&3^I&$0*1
M2_$``8)&1.H%"(M&W>D"`4_JF0$`)$7J`0D00QKK``I`1DE&W>D&B4OQ``O-
MZ1*KB.H`"$_P``O3Z3`C`"7-Z0)%3^I+%`.41$8/]NA)V>D`B;T'S>D,`47J
ME@48ZP((W>D6$DGK`PD#FV%`3^K:8D/JVF,#DPQ&#IE"ZDL2&.L!`$GQ``$`
M&4_JAG0`GHE&3^I*$0*12?$``8!&B4;=Z0(!N0@00T7J`0?6Z3(C1.H%!ACK
M``@Y1C!&S>D.`0_V=$'1Z0`!2?$`"=WI#$5/ZHMU@!C-Z1:)64'=Z1(C=$#-
MZ1@!!IEB0$_P``E/ZD@6%$9/ZDD7"D;=Z1@!1^K89T_JV6.`&`.3`I=!\0`!
M`AE%ZIH%0?$``\WI!B/=Z0(C3^J*=$_JFP%$Z@4*,D/=Z09G1>H!"U1&MAA'
M\0`'748R1MWI#JL[1LWI$B,`F@`C'T8/]N`\W.D`O'D!BNH$"M+I-"/-Z09%
M5$8;ZP(+3^J)=4SK`PQ!ZM9CW>D6$O(.`Y-"ZD<284!%ZI@%`)L,1@R9&^L!
M`$SQ``$`&4_JB'2+1D_J1A$"D4OQ``&"1D3J!0B+1MWI`@%/ZID!`"000T7J
M`0D:ZP`*T^DV(TOQ``O-Z1:K3_``"T!&248`)<WI`D5/ZDL4`Y2]!]WI!HE%
MZI8%S>D,`8CJ``A$1@_V-#G9Z0")&.L""-WI$A))ZP,)`YMA0$_JVF)#ZMIC
M`Y,,1@Z90NI+$ACK`0!)\0`!`!E/ZH9T`)Z)1D_J2A$"D4GQ``&`1HE&W>D"
M`;D($$-%Z@$'UNDX(T3J!088ZP`(.48P1LWI#@$/]LPAT>D``4GQ``G=Z0Q%
M3^J+=8`8S>D2B5E!W>D6(W1`S>D8`0:98D!/\``)3^I(%A1&3^I)%PI&W>D8
M`4?JV&=/ZMEC@!@"EP.30?$``0(91>J:!4'Q``/-Z08CW>D"(T_JBG1/ZIL!
M1.H%"C)#W>D&9T7J`0M41K881_$`!UU&,D;=Z0ZK.T;-Z18C`)H`(Q]&#_8X
M+-SI`+QY`8KJ!`K2Z3HCS>D&151&&^L""T_JB75,ZP,,0>K68]WI$A+R#@.3
M0NI'$F%`1>J8!0Q&#)D;ZP$`3/$``0`93^J(=$_P``R+1D_J1A$"D4OQ``&"
M1D3J!0B+1MWI`@%/ZID!$$-%Z@$)&NL`"D!&2_$`"\WI$JL`FTE&W>D&14_P
M``O-Z0P!3^I+&=/I/"-$0`_VG!'1Z0`!2>K::<WX")!/ZDH8@!A/ZH=U64'=
MZ18CS>D8`4_JVV,.F6)``Y-%ZI8%%$8*1MWI&`&`&$'Q``$"&4'Q``/-Z0XC
MW>D"([0'N0@`(T+J"`+=Z0Z)`)X8ZP((2?$`"<WI%HE"1LWI`B-$Z@4"1>H!
M`];I/F=/ZIL%'$831@.:S>D.-$_J0AG=Z0P264`/]@@3T^D`(Y(9>T$?1@*;
M2>K3:=WI$C1+0!A&!IO6&`*;1_$`!S(83^J*=D_J0QA'\0`#2.H)`$_JBW<2
M&$?JF@=#\0`#WND`B1%&#?4>?AI&1^H%`\WI$A(`(@A&$49&Z@<"'T;=Z0XT
M3^I!&Q9&S>D&9U-`2^K0:T_J0!H<1@_VB`/3Z0`C$NL(`D/K"0/=Z1:)'T8,
MFXCJ!`A+Z@H$UAC=Z0*K1_$`!Q;K"`)'\0`#$AE#\0`#3^J+><WI%B,`)!-&
MS>D`-%M&2>J:"4_JBGB?"$CJ"01)Z@<%7JO=Z09X+D8E1@&<;T#3Z0`C#_8<
M"=GI`(E/ZD0;`)P8ZP((S>D"5DGK`PE+ZM1K#IQ"1DM&$AG=Z1*)`)Q#\0`#
MB.H'"$_J@7E)ZI`)CPA/ZD0:1D:4&4KJ"P)#\0`%3^J`>!3K`@I(Z@D$1?$`
M"TGJ!P7=Z0*))D8O1F"IB.H$"-WI%D71Z0`!`".$Z@@$S>D,9P_RF'?7Z0!G
M4D:@1@:<S>D.JS883^I#&T]!2^K::S893^I*&D?Q``=+Z@H`%NL(!$?Q``44
MZP`*1?$`"]WI`$501LWI$JM/\``*3_``"T_JA7E/ZH1X2>J4":\(S>D`JV*L
M2.H)"DGJ!PO=Z0QX84;4Z0!%3@'-Z0:KA^H*!P_R''K:Z0":`989ZP0)`9Q*
MZP4*RT9$ZM!DW>D.B4_J@WD!E$GJD@D"G(CJ!PB?"&2K&^L$!$9&2O$`!4_J
MT&BB1D0!`)0:ZP8$1?$`!4CJ01BB1JM&W>D`14GJ!P5$Z@@$3^J">!KK!`I(
MZ@D$W>D&B4OQ``O-Z1:K3_``"\WI`*LF1M/I`",O1@&<B.H&",WI`F=/ZH%Y
M#_*$9M;I`%9)ZI`)3^I$&ZT87D$`FS=&2^K3:]WI$C0,G(/J"`-/ZH!X+AD`
MG$?Q``=/ZD0:]!A*Z@L&1_$`!8L(%.L&"T7Q``Q(Z@D$2>H#!6:IH$;=Z0(C
MT>D``:E&S>D.B0`G#_(<:=GI`(EB0`:<7D88ZP`(S>D,O$GK`0E/ZD<;0$9+
MZM9K24;=Z1:)`!E/ZD8:B.H""$'Q``%/\``,0D:$&$KJ"P!!\0`%%.L`"F%&
M1?$`"]WI`$501LWI$JM/ZH5Y3^J$>$GJE`EHK*L(2.H)"M3I`$5)Z@,+4D;=
MZ0Z:6T8/\IQ;V^D`J\WI%D4`),WI!B,`)<WI`$5,`0&4B>H""=WI%C3"#D+J
M3!)/ZH9X$^L*`T3K"P2:1@&;HT9#ZM!C`9/=Z0PT`IR#Z@D#3^J'>1KK!`1)
MZI8)2_$`!6JNHD9$`0"4&NL#!$7Q``4`(Z)&JT;=Z0!%O0@40QKK!`I+\0`+
MS>D6JU)&S>D`(TGJ!0-(Z@D"W>D&B=;I`*N(Z@((B>H#"<WI#",`(D1&348/
M\O!)V>D`B0`CS>D"(QCK"@A)ZPL)PD;+1MWI`(E#1ML.`I,"FT/J21/=Z1*)
M`I.(Z@0(#IR)Z@4)S>D2B1KK!`-/ZI$%2_$`!-WI`*N81FRI4T9/ZH!Z7@%;
M1ML.`Y,2FT_JC'M+ZI`+&.L#"$3Q``E"1DM&W>D"B4CJ!@@2ZP@&2NH+`D/Q
M``=+Z@4#L$;1Z0!%N4;=Z0QGS>D.(T_J2!H60\WI$HE/\``),$;=Z19G3^I)
M&P9`2^K8:S!&W>D,9Q9`#_(T0]/I`",P0TOJ"@82&=WI`*MK01U&!IO2&$7Q
M``,2&$/Q``/-Z0(C6T:=!U-&W>D"JY@(;JL:ZP8*W>D`9TOQ``O-Z1:K3_``
M"\WI`*M%ZI8%0.J'<+0'N0A$Z@`*1>H!"]WI#D7-Z0:KW>D2O$3J"@+3Z0`!
M"^H""PR;`9Y:1MWI!JL/\JP\W.D`O`"?!.H*!!OK``M/ZD863.L!#!OK`PL`
MFT;JUV8#ED+J!`9,\0`,&^L&"T_JTV1/ZD,3`I-,\0`,`9M/ZHEQW>D"9T'J
MF`%/ZHAP1.I#%$_JF0,F0]WI!D4;ZP8+3_``"4SQ``S-Z1*\V$9`Z@$+0>H#
M#$3J"P+-Z0R\<*O=Z1:K3^I)%MWI#+Q&ZMAF"NH""M/I``$$Z@L$#IM21@_R
M"#O;Z0"K`Y9"Z@0&&NL`"D_JV&1+ZP$+&NL#"D_J2!,"DTOQ``L:ZP8*W>D"
M9T3J211+\0`+`"<F0S1&`9X:ZP0*`9Q+\0`+S>D6J[$'`)ZC"-WI#$5!ZI8!
ML`=!Z@,+5D9`Z@$*S>D.J]WI$KQ$Z@H"<JO-Z0!G"^H""P&>T^D``5I&W>D.
MJP_R@"S<Z0"\=@$&FP3J"@0;ZP`+`)],ZP$,&^L#"P";3/$`#$;JUV8#ED+J
M!`9/ZHEQW`Y;`0*3&^L&"P&;0>J8`=WI`F=,\0`,3^J(<$3J0Q1/ZID#)D-/
M\``)&^L&"T_J219,\0`,S>D2O$'J`PQTJ]A&0.H!"]/I``%&ZMAFW>D.1<WI
M!KQ$Z@L"W>D6J]WI!KP*Z@(*#)L$Z@L$`Y921@_RW!O;Z0"K0NH$!D_JV&0:
MZP`*1.I)%$OK`0L:ZP,*3^I($P*32_$`"QKK!@K=Z0)G2_$`"P`G)D,T1@&>
M&NL$"@&<2_$`"\WI%JNQ!P">HPC=Z09%0>J6`;`'0>H#"U9&0.H!"LWI#*O=
MZ1*\1.H*`G:KS>D`9POJ`@L!GM/I``%:1MWI#*L/\E0<W.D`O'8!#IL$Z@H$
M&^L`"P"?3.L!#!OK`PL`FTSQ``Q&ZM=F`Y9"Z@0&3^J)<=P.6P$"DQOK!@L!
MFTSQ``S=Z0)G0>J8`4_JB'!$ZD,43^J9`R9#W>D,11OK!@M/\``)3/$`#,WI
M$KS81D#J`0M!Z@,,1.H+`LWI#KQXJ]WI%JM/ZDD6W>D.O$;JV&8*Z@(*T^D`
M`03J"P0#EE)&#_*T"]OI`*L&FT+J!`8:ZP`*3^K89$OK`0L:ZP,*3^I($P*3
M2_$`"QKK!@K=Z0)G1.I)%$OQ``L`)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`
MGJ,(W>D.14'JE@&P!T'J`PM61D#J`0K-Z0:KW>D2O$3J"@)ZJ\WI`&<+Z@(+
M`9[3Z0`!6D;=Z0:K#_(L#-SI`+QV`0R;!.H*!!OK``L`GTSK`0P;ZP,+`)L)
MX*_S`("AZ]EN`````-R\&X\`````3/$`#$;JUV8#ED+J!`9/ZHEQW`Y;`0*3
M&^L&"P&;3/$`#-WI`F=!ZI@!3^J(<$3J0Q1/ZID#)D/=Z09%&^L&"T_P``E,
M\0`,S>D2O-A&0.H!"T'J`PQ$Z@L"S>D,O'RKW>D6JT_J21;=Z0R\1NK89@KJ
M`@K3Z0`!!.H+!`Z;4D8/]I1KV^D`JP.60NH$!AKK``I/ZMAD2^L!"QKK`PI/
MZD@3`I-+\0`+&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"DOQ``NQ!P">
M`9S-Z1:K0>J6`;`'HPC=Z0Q%0>H#"U9&0.H!"LWI#JO=Z1*\1.H*`GZKS>D`
M9POJ`@L!GM/I``%:1MWI#JL/]@QLW.D`O'8!!IL$Z@H$&^L`"P"?3.L!#!OK
M`PL`FTSQ``Q&ZM=F`Y9"Z@0&3^J)<=P.6P$"DQOK!@L!FTSQ``S=Z0)G0>J8
M`4_JB'!$ZD,43^J9`R9#W>D.11OK!@M/\``)3/$`#,WI$KS81D#J`0M!Z@,,
M1.H+`LWI!KR`J]WI%JM/ZDD6W>D&O$;JV&8*Z@(*T^D``03J"P0,FU)&#_9L
M6]OI`*L#ED+J!`8:ZP`*3^K89$OK`0L:ZP,*3^I($P*32_$`"QKK!@K=Z0)G
M1.I)%$OQ``L`)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`GJ,(0>J6`;`'0>H#
M"X*K5D9`Z@$*S>D`9]/I``'=Z09%S>D,J]WI$KQ$Z@H"#IL+Z@(+`9X`GUI&
MW>D,JP_VW$S<Z0"\=@$$Z@H$1NK79AOK``L#EDSK`0P;ZP,+`)M"Z@0&3/$`
M#!OK!@M,\0`,3^J)<=P.6P$"DT'JF`$!FT_JB'#=Z0)G1.I#%$_JF0,F0]WI
M#$4;ZP8+3_``"4SQ``S-Z1*\V$9`Z@$+0>H##$3J"P+-Z0Z\A*O=Z1:K3^I)
M%MWI#KQ&ZMAF"NH""M/I``$$Z@L$!IM21@_V0$O;Z0"K`Y9"Z@0&&NL`"D_J
MV&1+ZP$+&NL#"D_J2!,"DTOQ``L:ZP8*W>D"9T3J211+\0`+`"<F0S1&`9X:
MZP0*`9Q+\0`+S>D6J[$'`)ZC"-WI#D5!ZI8!L`=!Z@,+AJM61LWI`&=`Z@$*
M`9[3Z0`!1.H*`LWI!JO=Z1*\=@$,FPOJ`@L`GUI&W>D&JP_VL#S<Z0"\1NK7
M9@3J"@0#EAOK``M"Z@0&3.L!#!OK`PL`FTSQ``P;ZP8+3^J)<4SQ``Q!ZI@!
MW`Y;`0*33^J(<`&;W>D"9T3J0Q1/ZID#)D/=Z09%&^L&"T_P``E,\0`,S>D2
MO-A&0.H!"T'J`PQ$Z@L"S>D,O(BKW>D6JT_J21;=Z0R\1NK89@KJ`@K3Z0`!
M!.H+!`Z;4D8/]A@[V^D`JP.60NH$!AKK``I/ZMAD2^L!"QKK`PI/ZD@3`I-+
M\0`+&NL&"MWI`F=$ZDD42_$`"P`G)D,T1@&>&NL$"@&<2_$`"\WI%JNQ!P">
MHPC=Z0Q%0>J6`;`'0>H#"U9&0.H!"LWI`&?-Z0ZK1.H*`MWI$KR*JP&>`)\+
MZ@(+T^D``5I&=@'=Z0ZK1NK79@_VA"S<Z0"\`Y8$Z@H$!IL;ZP`+3.L!#$+J
M!`8;ZP,+`)M,\0`,&^L&"TSQ``Q/ZHEQW`Y;`0*30>J8`0&;3^J(<-WI`F=$
MZD,43^J9`R9#W>D.11OK!@M/\``)3/$`#,WI$KS81D#J`0M!Z@,,1.H+`LWI
M!KR,J]WI%JM/ZDD6W>D&O$;JV&8*Z@(*T^D``03J"P0,FU)&#_;L&]OI`*L#
MED+J!`8:ZP`*3^K89$OK`0L:ZP,*3^I($P*32_$`"QKK!@K=Z0)G1.I)%$OQ
M``L`)R9#-$8!GAKK!`H!G$OQ``O-Z1:KL0<`GJ,(W>D&14'JE@&P!T'J`PM6
M1D#J`0K-Z0RKW>D2O$3J"@*.J\WI`&<+Z@(+`9[3Z0`!6D;=Z0RK#_9D'-SI
M`+QV`0Z;!.H*!!OK``L`GTSK`0P;ZP,+`)M,\0`,1NK79@.60NH$!D_JB7'<
M#EL!`I,;ZP8+`9M,\0`,W>D"9T'JF`%/ZHAP3_``"D3J0Q1/ZID#)D-71AOK
M!@M`Z@$*3/$`#,WI&+Q>1D'J`PM31D_P``A<1MWI#*M/\``)S>D"B4KJ`PC-
MZ0XT?`$#E$)&W>D.1=WI%HF0J0KJ!`G-Z1)G".H""-'I``%,1@_VL`S<Z0"\
M0D;=Z1*)`YX;ZP`+3.L!#`:;049&ZMAF1T8#EDD!`9X"D5A&0NH$"_P.W>D"
M>,(81.I)%$SQ``,G0Q+K"P(!G$_JAG$`GD/Q``,2ZP<+3_``!T/Q``RC"$'J
ME@&P!UY&S>D`9\WI%KP`)$'J`PP`(\WI`C22J@&;0.H!"]WI#F?=Z1B)X4;2
MZ0`!6P%&Z@L"`Y,(Z@((!NH+`@.>1$;81@_V"`S<Z0"\(D,W1@">&^L`"PR;
M3.L!#$?JUF<`GEA&P!A,\0`!@AA/ZD83`Y<"DT'Q``.[1A9&'T;=Z0(C3_``
M#$+J"P(6ZP(*1_$`"]WI$F?-Z1BKTT;-Z0*\O0>T!T7JE@6Y"$3J!0I%Z@$+
M`YN4J=WI%D7-Z1*)B.H*"`*:A.H(!,WI!JM;`='I`+R@1@_R@''1Z0`!0^K2
M8PZ<&^L`"Q]&3.L!#%,!&^L$!`">3/$`!13K"`I#Z@<(`9M%\0`+M`<!GAKK
M"`I/ZH-U`)O11DOQ``NQ",WI%JM%ZI,%2D9%Z@$(1.H%!Y:I3_``"CU&1D;=
MZ09X4T;-Z0Q6;T#=Z1A%T>D`B7Q`#_((<='I``'-Z0`C`"<F1A*<&.L`"`";
M2>L!"1CK!`1)\0`%W>D`B=@.`YM/ZD<;3^I(&A3K!@A`ZDD01?$`"9T'`IM*
MZ@`&&.L&"$7JDP4"FT9&2?$`"<WI$HE+ZM9KG`<#FT3J!0A/ZD8:F0A`1D7J
M`0F8JTE&W>D,B=/I`".(Z@`(S>D.`41&#_)\:=GI`(D8ZP((2>L#"=WI%B,&
MF0`C8D`8ZP$`%$9)\0`!$.L$"$KJ"P3=Z0"\0?$`"0`BS>D"(T_P``H8ZP0(
M84951D_J@7$#D0.8649/ZI$"1$9`ZIL!`Y%91D_P``!/ZH%Q`I%A1D+JC')/
MZI$#3_```<WI``%)\0`)W>D"`<WI%HG!1AE#$$-K`0&3BT;=Z0X2FJN"1D%`
MS>D"J]/I`+R(1@_RV%+2Z0`2`9L;ZP$+#)E,ZP(,0^K98QOK`0`!D]WI$B-,
M\0`!NPB"Z@@"BT9A`0"1D$;B#A#K"`#=Z0")0NI%$DOQ``%(Z@((3_``"1#K
M"`I/ZH9P0?$`"[D'0>J6`<WI$JM!Z@,,0.H!"T_J21,`)EE&8D;=Z0*\`"?-
MZ0!GT$8!DXOJ`0N<J\WI!A)>1@Z9T^D`JP_R0%/3Z0`C&NL""DOK`PL!FQKK
M`0!#ZMAC`9/=Z18C2_$``:L(<D"+1D_J2!$`D19&3^K88H`9W>D`9T+J21)+
M\0`!%D,`)Q#K!@I/ZH1P0?$`"ZD'0>J4`59&S>D.JP`D0.H!"D'J`PL`)7L!
MS>D`15%&`9/=Z08TS>D,JTM`WND`O`_RO$+2Z0`2#?4@?AQ&`9L;ZP$+`IE,
MZP(,0^K68QOK`0`!D]WI$B-,\0`!3^J9`T_P``QB0(M&<0$`D11&\@X`&=WI
M`$5"ZD<22_$``11#9480ZP0*3^J(<$'Q``M/ZHEQ0>J8`51&0.H!"$'J`PG-
MZ1*K:P'"1@_R1$+2Z0`2RT;-Z0*KWND`O$/JU&/=Z0R)#?4D?AOK`0L&F0&3
M3.L"#-WI#B,;ZP$`3/$``8CJ"@B"Z@@"NPB+1F$!`)&01N(.$.L(`-WI`(E"
MZD422_$``4_P``E(Z@(($.L("D_JAG!!\0`+N0=!ZI8!S>D.JT'J`PQ`Z@$+
M3^I)$P`F`"?-Z0!G`9.BJ]!&649B1MWI`JO-Z082T^D`O(KJ`0KHH]/I`",,
MF59&&^L""TSK`PP!FQOK`0!#ZMAC`9/=Z1(C3/$``:L(<D"+1D_J2!$`D19&
M3^K88H`9W>D`9T+J21)+\0`!%D,`)Q#K!@I/ZH1P0?$`"ZD'0>J4`0`E0>H#
M#``D>P'-Z0!%`9-61MWI!C3-Z1*K0.H!"X/J"P/-Z0R\WND`$@WU)GX/\A0[
MV^D`JQQ&`9M/\``,$>L*`4+K"P)#ZM9CBD8"F0&3DT8:ZP$`W>D.(TOQ``%/
MZID#8D"+1G$!`)$41O(.`!G=Z0!%0NI'$DOQ``%E1A1#$.L$"D_JB'!!\0`+
M3^J)<4'JF`%41LWI#JM`Z@$)0>H#"M[I`!)K`0WU*G[31LI&W>D,B4/JU&/-
MZ0*KB.H*"`_RA"O;Z0"K`9,1ZPH!0NL+`HI&!IF31MWI$B,:ZP$`3^J7`TOQ
M``&"Z@@"BT9A`0"1D$;B#A#K"`#=Z0")0NI,$DOQ``%/\``)2.H""!#K"`I/
MZH9P0?$`"[D'0>J6`0`G`";-Z0!G0.H!!D'J`P?=Z0(23^I)$P&3J*MQ0-!&
MS>D&9\WI$JL.1@_R^!O;Z0"KT^D`$@&;$>L*`4+K"P)#ZMACBD8,F9-&`9/=
MZ0XC&NL!`$OQ``&K"')`BT9/ZD@1%D8`D8`93^K88MWI`&="ZDD22_$``0`G
M%D,0ZP8*3^J$<$'Q``NI!T'JE`$`)4'J`PP`)'L!S>D`10&35D;=Z08TS>D.
MJT#J`0N#Z@L#S>D,O-[I`!)/\``,#_)H&]OI`*L<1@&;#?4L?A'K"@%"ZPL"
M0^K68XI&`ID!DY-&&NL!`-WI$B-+\0`!3^J9`V)`BT9Q`0"1%$;R#@`9W>D`
M14+J1Q)+\0`!94840Q#K!`I/ZHAP0?$`"T_JB7%!ZI@!5$;-Z1*K3_``"$'J
M`PI/\``)S>D`B4#J`0E21FL!248!D\WI`A+>Z0"K#?4P?C6CT^D`(]WI#(D:
MZP(*2^L#"XCJ`0@!FP:90^K48P&3&NL!`-WI#B-+\0`!NPB"Z@@"BT9A`0"1
MD$;B#A#K"`#=Z0")0NI,$DOQ``%/\``)2.H""!#K"`I/ZH9P0?$`"[D'0>J6
M`=!&S>D.JT#J`0I!Z@,+`"8`)\WI`&=61E]&W>D"JT_J21,!DZZKBNH&"A&B
MTND`$LWI!F=61M/I`*L!FQKK`0I#ZMAC`9,,F4OK`@O=Z1(CJP@:ZP$`2_$`
M`7)`BT9/ZD@1">"O\P"`W+P;CP````#6P6+*``````"1%D9/ZMAB@!G=Z0!G
M0NI)$DOQ``$`)Q9#$.L&"D_JA'!!\0`+J0=!ZI0!`"5!Z@,,`"1[`<WI`$4!
MDU9&W>D&-,WI$JM`Z@$+@^H+`\WI#+S9HM+I`!)/\``,WND`JQQ&`9L-]3)^
M&NL!"@*92^L""T/JUF,:ZP$``9/=Z0XC2_$``4_JF0-B0(M&<0$`D11&\@X`
M&=WI`$5"ZD<22_$``11#9480ZP0*3^J(<$'Q``M/ZHEQ0>J8`51&0.H!"<WI
M#JM!Z@,*WND`$FL!#?4V?M-&RD;=Z0R)0^K48\WI`JN(Z@H(#_+0*]OI`*L!
MDQ'K"@%"ZPL"BD8&F9-&W>D2(QKK`0!/ZI<#2_$``8+J"`*+1F$!`)&01N(.
M$.L(`-WI`(E"ZDP22_$``4_P``E(Z@((3_``#!#K"`I/ZH9P0?$`"[D'0>J6
M`0`G`";-Z0!G0.H!!D'J`P?=Z0(23^I)$P&3M*MQ0-!&S>D&9\WI$JL.1@_R
M0"O;Z0"KT^D`$@&;$>L*`4+K"P)#ZMACBD8!DPR9DT;=Z0XCJP@:ZP$`2_$`
M`7)`BT9/ZD@1`)$61D_JV&*`&=WI`&="ZDD22_$``0`G%D,0ZP8*3^J$<$'Q
M``NI!T'JE`'-Z1:K0.H!!$'J`P5/ZD<;5D8A1MWI!C0J1LWI#!)+0&^AT>D`
M`4OJVFO-^`"P'$;>Z0`C3^I*&@WU.'X2&$M!S>D.(]WI$B/[#@*98D`!DQ1&
M"D;=Z0X!@!A!\0`!`AG=Z0!%0?$``T_JB7'-Z0(C1.H*!$'JF`'=Z0*K3^J(
M<$_JF0-`Z@$(0>H#"1KK!`I"1F5&2T;=Z0R)S>D.(U1&S>D`18CJ`@A-I-3I
M`#1+\0`+W>D614_JEPG>Z0`2A.H(!,WI$JO)&$_JAWN@1@"<2^J6"[JO2^H)
M!0`CX`X&G*Q&"AD!G!+K"`)`ZD00`)Q/ZD0:0.H*`$_JAGI*Z@L$W>D.FA(8
MU^D`9Z-&BNH%"HGJ"PG-Z0:\7`$`(\A&T48/\KP+V^D`JT3JTF[=Z1*\S?@,
MX!KK!@J,Z@D,B^H("\WI$KQP1@R<3_``"=WX],(:ZP0&5`$"E!*<-AG=Z0)%
M!$,@1@"<-AC=Z0@!`"&`&4_JE`H:GMWI`$7&Z0`!2NJ%>MWI$%8;F4_JA'BM
M&$CJ"@@J1M'X`.#=Z0I6!IEM&`Z9+D;=Z11%`"5D&-WI!`$`(1#K"`"P1AJ>
M]$7&Z0(CQND&B<;I"$7&Z00!`]$-]3]]O>CPC_SW%NT`OZ_S`(#6P6+*````
M`"WI^$,?2WM$`"@YT!Y*FUC3^`"0N?$`#S#0!7@`+1B_/2T4OP$E`"45T=GX
M`$!\L0=&B$9.1BI&.48@1OSW_.T0N6-=/2L/T%;X!$\`+/+1($:]Z/B#!485
M^`$_`"L8OSTK^=$M&N#G`36FZPD&+$2V$,CX`&`@1KWH^(-,1N?G!$;EY_ID
M`0!0`0``\+6#L!5/!4852VQ&?T3^6#-H`9,A1BA&__>L_["Q$4L`F/M8&6@!
MZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&*$;_]Y;_`"CHT0&:,VB:0@'1
M`[#PO?SWFNQH9`$`&`$``%`!```MZ?!/#$;?^%R1A;!62P9&^40*>%GX`U`]
M*@B_`30K:"!&`Y/\]_KL`JD'1C!&__=M_X!&`"A3T/SW\.R'0D;92DL"FEGX
M`Y!/ZH((,'@`*!B_/2@4OP$@`"`'T#!&$/@!/P`K&+\]*_G1@!L"-]GX`*`X
M1/SWKNQ*^`@``"AKT-GX`"!Q'`*8,WA2^"``/2L8OP`K`W`)T$(<$?@!.Q!&
M`"L8OSTK`O@!._;1`D8](P-P%/@!.P+X`3\`*_G1`"`#FBMHFD)*T06PO>CP
MCPCQ_S`4^`$[`/@!/P`K^='NYR)+6?@#D-GX`+#;^``P@[-;1@#@4$93^`0O
M`/$!"@`J^-$#,(``&DIZ1!-HB[$!1EA&_/<>[,GX``#HL4_JB@@#1@KQ`0(`
M(4/X(A#-^`B@C.<!(Q-@_/=.[`&08+%/ZHH(649"1OSWP.L!F\GX`##GYYI&
M""#6YT_P_S"PY_SWY.L`O_QC`0`8`0``4`$``+AD`0`T2S5*>T0MZ?!#G[">
M6#-H'9,0L0-X!T8SN1V:,VB:0E71'["]Z/"#_/<.[`5&`"CST-_XJ(#X1"A&
M_/>R[``H.]##?-/Q+@,'T0-]`"OST-/Q+@,4OUM"0WT`*^S0`/$3!#A&_/<@
M[(%&($;\]QSL2$0",/SW].M#1D_P_S(!(0&4`)>!1OSW+NQ)1@*J`R#\]YCL
M`3!(1@70!IL#]'!#L_6`3Q#0_/>4ZTA&_/=8ZRA&_/=V[``HP]$H1OSWH.PX
M1OSW8.NHY__WFO_MY_SW<NL`OY1B`0`8`0``OA,``#BU!4852Q9*>T2<6"!H
M_/>.["E&`/6D<@,@_/=\[`BQ`"`XO2!H_/>"[-#X6#$#]'!#L_6`3PG0(&C\
M]WCLT/A8,0/T<$.S]2!/Z=$H1@(A_/<D[+#Z@/!`"3B]L&$!`"`!```MZ?!#
MK?6`72%-@[`A2PWU@%9]1`&L@$8?2.]8!#:)1D#V_W(A1GA$.V@S8/SW1NL`
M*"'=1AZC7>.Q!D8R1B\A($;\]_3KN+$42^M8&&C\]SSL,T8B1D%&_/<&[`WU
M@%,$,QIH.VB:0A#1#?6`70.PO>CP@P`NX=$(2^M8&&C\]R3L2D9!1OSW%.OG
MY_SW\.I"80$`&`$``)(2```@`0``$+4(3`A+?$3C6!AH_/<,[`9*!TL'2:)8
M>T1Y1+WH$$#\]X*[KF`!`"`!```<`0``R!$```X2```-2PY*>T00M8*PG%@@
M:/SW\.O_]]G_(&C\]^KK`"$(2P&1"$I[1`A)>D0`DWE$_/>,ZP*P$+T`OWA@
M`0`@`0``O!0``!$.``#@$0``(4LB2GM$\+6M]0!=G5B'L`WU`%(#KA0R'4PK
M:'Q$$V#\]P+K&TM!\@$"`2%[1(WH$0`P1OSW(NL`*"';#?6`5S!&$#=/](!2
M.4;\]Z;J!!X6VV`<_/?0Z@9&*+$Y1B)&_/=6Z@`C,U4-]0!3,$84,QIH*VB:
M0@71#?4`70>P\+T`)O'G_/=BZBQ@`0`8`0``R!$``*P1``#_][*_+>GP3ZWU
M@5W?^'2!@[!=2P1&^$0-]8%26T@$,ECX`S`-\2@)#49X1*GQ"`$%DQMH$V#_
M]R_]+R$&1B!&_/>^ZIBQ4D@A1GA$__>>_2!&#?6!4P0S&F@%FQMHFD)`\(J`
M#?6!70.PO>CPCR!&_/>:ZD=)>42"1BA&_/<$ZP=&`"C?T$1+W_@0L7M$!I-#
M2_M$>T0'DSMX`"M+T"ZQ.48P1OSWN.D`*$K0.$;\]WSJ0AZ[&+I<+RH&T0`A
M&7`!.!/X`2TO*OG0"O$!`QA$L/6`7[?:J?$$!3)*`2%;1GI$`)<!DBA&3_2`
M4@*4_/=ZZBU+6/@#<#AH_/<(ZRE&`/6D<@,@_/?>ZDBY.&C\]_[JT/A8,0/T
M<$.S]0!/'-`B20`@>43\][#J!T8`+XK0.W@`*[/1;K$&F3!&_/=LZ>"Y&TD`
M('E$_/>>Z@=&`"_NT7CG!Y\!(+?G`2$H1OSWCNH`*-S1$T@I1GA$__<._2A&
M_/=&ZFSG_/><Z0:?`2"CYP"_@E\!`!@!```J$0``%A$``/H0``#$$```XA``
M`+P0``"<$```(`$``$P0```J$```]@\```-X.[%"'"\K"+\01A+X`3L`*_C1
M<$<`OSBUF+,%>`1&A;/\]^;I`3@B&)1"#-(C7"\K,-%3'@+@$7@O*2O1G$(:
M1@/Q_S/WT91"&=`!.@/@$7@O*031&D:40@+Q_S/WTQ(;DQRS]8!?$]@42"%&
M`3)/](!3>$0$1OSW.ND@1CB]+RT5T0(@_/>0Z1"Q+B("@#B]`"`XO5,>`N`1
M>"\IU="<0AI&`_'_,_?3E$+.T>?G`TB]Z#A`>$3\]\2Y-%\!``X/```MZ?!!
MC+!*3`*M2D]\1$I.##1_1-_X)($/S/A$OUD!K@_%#\S7^`#@#\4D:$1(S?@L
MX'A$+(#_]S?\0DAX1/_W,_Q!2'A$__<O_$!(>$3_]RO\/TAX1/_W)_P^2'A$
M__<C_#U(>$3_]Q_\/$AX1/_W&_Q`1O_W&/PY2'A$__<4_#A(>$3_]Q#\-TAX
M1/_W#/PV2'A$__<(_#5(,49X1/_WO?L8L0%&0$;_]S+\,4@Q1GA$__>S^R"Q
M`48O2'A$__<G_"Y(,49X1/_WJ/N(L0%&*TAX1/_W'/PJ22M(>41X1/_W%OP+
MFCMHFD(>T0RPO>CP@29(,49X1/_WD/LHL0%&(TAX1/_W!/SFYR))"B(-\1D`
M>43\]Y[I`"C=T1Y(#?$C`7A$__?T^];G_/>&Z`"_/`X```I=`0`8`0``.@\`
M`-(.``#4#@``U`X``-@.``#8#@``X`X``'0.``#<#@``Y@X``&(.``#B#@``
MY@X``.@.``#H#@``\`X``/(.```&#@``#`\``$X.``#2#@``1@X``,H.```F
M#@``$DD32GE$$TL0M7M$C%B"L!AH(V@!DT,<!=`!FB-HFD(2T0*P$+T,2&E&
M>$3_]RC[,+$`>#`H&+\`*!2_`2``(`9+>T088.CG_/<HZ'Q;`0`8`0``TEP!
M`((-``":7`$`"+7[]^;O^_?8[P"Q`&@(O2WI\$\&1B],D;#?^+S@"*U\1-_X
MN,`$-/Y$+T8/S%[X#(`/QY3H!P#8^``P")R'Z`<`#Y/\L=_XF*`'K]_XE)#Z
M1/E$!N`Q1OOWG._8L57X!$^$L3E&($;_]]KZ@T80L0)X`"KOT2!&,4;_]TO[
M5?@$3P`L[M$/FMCX`#":0A_1$;"]Z/"/,$;\]TKH!9!81OSW1N@%FQA$`C#\
M]Q[HS?@(L%-&S?@$D$_P_S(`E@$A!9#\]U3H!9D@1O_W(_O&Y_OWM.]<7`$`
M^%H!`!@!``"L#```I@P``"WI\$^M]0%-W_AL1Y.P4JO?^&B'?$0+DP3Q(`(>
M1M_X8#?X1`R0IO'X!P?*!/$L#ECX`S"F\>`+1#2F\>P)VD;\/AU&#9.'Z`<`
MON@/`-7X`,"JZ`\`#?4!0Y[H`P!$,\/X`,"*Z`,`E.@'`(GH!P`Q1M_X$`=X
M1/_W7OH@L0-X!$8`*T#PBX'_]T;_!48`*%S0*$;[]]CO0``!,/OWL.\K>(%&
M@['?^."F3$;Z1`"3($931D_P_S(!(0(T^_?B[Q7X`3\`*_+1"YM3^.`,&+D5
MX%OX!`^0L3%&__<M^@1&`"CVT`-X`"OST/_WR?L`*._0($;[]]3O!48`*#71
M`"17^"10A;,K>'.S*$8$\0$*!^N$!/_WM/M8N53X!%\=LRMX"[,H1@KQ`0K_
M]ZG[`"CST"A&5$;[][3O`"C@T`5&$^#[]Z[O`"A`\#F!6?@$"P`H`/`K@3%&
M__?N^0`H]=`#>``K\M#LYP`E*$;?^!QV^_=J[W]$!$9(1OOW9N\$1`3R!$0@
M1OOW/._?^`0V3_#_,@$A>T0!D]_X^#7-^`R0>T0`E0*7@T;[]VSO6$9/].!Q
M^_>$[P$P+M#?^-PU6/@#<#AH^_?R[UE&`/6D<@,@^_?@[P5&`"@UT-_XP`4!
M(0R;`"3?^+@E6/@``!MH>D3-^`"P`&C[]X#O#?4!0R!&1#,::`V;&VB:0D#P
MG((-]0%-$["]Z/"/^_<N[P)H$2K+T-_X>`4!(0R;`"18^```&V@!DM_X;"7-
M^`"P>D0`:/OW6N_9YSAH^_>P[]#X6#$#]'!#L_6`3[_1.&C[]Z;OT/A@D?OW
M0.Z!1;;1.&C[]Y[OT/A8,</S"`.S]>!_K-$@1OOWONXQ1@1&W_@<!7A$__=2
M^0`H`/"4@`R;'FC[]P#O`48P1O_W_?L&1@`H`/"(@#!&^_?([@,H!T80W=_X
M[!0$.#!$>43[]_;M0+D$+P#PX($W1!?X!3PO*P#PVH'_]^K],+D!1C!&^_>$
M[@Z0`"AIT=_XN!3?^+@$>43?^+AT>$3?^+24__>0^7]$^_>0[M_XK#3?^*P4
M3_#_,GM$`9/?^*0T>43?^*"$ND8#D7M$S?@`L`$A^43X1%]&`I`@1OOWH.X4
MX/OWENX#:!$K%]'[]V[N`37-^!"`,D8#E4M&S?@$H`$A`)<"D"!&^_>*[D_T
MX'$@1OOWH.Y#'`9&XM"[1EA&^_>\[=_X1`0A1GA$__=+^2!&__?&_2WG__?#
M_2!&^_=\[@1&)N<-(-_X)%3[]R;N4R-]1(%&<^8%1F?F#)L>:'3G"Y]O\!$"
M`B4`E3L?#),>1D_P_S/[]_CM,48&(@Z8^_=Z[1?X!#P;N7-X0RL`\'*!`"4`
M(@`C`)4.F/OWYNT+GM&AT>D``:;QR`K1H]/I`"/*^'A0RND"`:;QD`$/D<ZA
MT>D``<KI!"/-H]/I`"/*Z08!S:'1Z0`!RND((P`B`",0E,KI"B/*Z0PC1NDR
M`<WX1+!/]`!"#)D.F/OW/.T$'GK=YQ?:Z0HC)D;Y`$'J5'$'D>$`!I'=Z0:)
M3_``"1CK`@B910B_D$7:Z0PC`M(!,D/Q``-Q#]KX>`!!ZL<!")%Y#PF1W>D(
M5LKI"HFM&%Y!*D8S1LKI#",`*$K0P/%`"`^;H$4,F1A$J+^@1D)&^_<@[=KX
M>#!#1,KX>#!`*[C1#)M01J3K"`281/OWW?\_+";=0#P+G23P/PL(\4`,"_&`
M"<%$K/%`!J7QD`XP:!`V5O@,''=&5O@(+`[Q$`Y6^`0\9D4/Q_'14$;[][W_
M!O%`#,Q%YM$+\4`+!/`_!-A$049((R)&#YC[]RSMROAX0'_GW?@P@,KG"YL.
MF*/QD`<0G-WX1+#[]PSNVO@H4(`AVO@P8,7SQ0)3'#@KN50`\YJ`^!C#\3@"
M`"'[]YKM4$8J#C,.BOAT((KX<V"*^'=0BOAP,#,,-@J*^'$PBOAR8"L,+0J*
M^'4PBOAV4/OW=/\+F-KX"&"@\40"VO@04%#XR.R@\3`'H/$("-_X])'5<D_J
M'D%/ZAYC47#Y1-KX(!``^$0\VO@8`(+X`^!/ZAXNT72"^`+@3^H6;M!S@O@$
MX$_J%DZ"^`7@UG$V"I9Q+@X6<BX,+0I6<I5R%D8%#A5S!0P`"E5S/4:0<P@.
M$'0(#`D*4'21=`'@%O@!/P"3*$9+1D_P_S(!(0(U^_<0[:A%\M%<2$_P_S);
M2P$A>$0"EP.0>T3-^`"P($8!DP`CA_@H,%9+>T3[]_KL=^8,FU]H`"\_]"&N
M.$;[]]+L`RA_]ANN3TD$.#A$>43[]P+L`"@(OSY&$.;#\4`"^!@`(?OW`.U0
M1OOW\/XX1C@B`"'[]_CL7.<,FYMX02M_](FN#)O;>$,K?_2$K@R;&WE(*W_T
M?ZX,FUMY12M_]'JN`)5/\/\S#IUO\#D"*$;[]U[L#)XH1BDB,TTQ1OOWW.LR
M2WU$3_#_,GM$`9,P2P$A`I8@1LWX`+![1`.5^_>@[![F^_<&[`"_K_,`@(FK
MS>\`````_MRZF`````!V5#(0`````/#ATL,``````2-%9P````"`6P$`%EH!
M`!@!``!^"P``9`P``+`+``"("@``>`L``"`!```H`0``O@L``/`*``!B#```
MH@H```@*``!B"0``$`D``&`*``#^"```=@L``%@*``!B"P``9`@``%`)```>
M!P``*`@``*(%``#L!@``P`8``'8'``#P!```/`8``)5*EDDMZ?!/>D2'L)1+
M!*T"E5!8`6@#D`61UE@P:/OWRNP$1C!H^_?&["E&D/AD,(Q(A/AE,'A$_O>"
M_ABQ`W@Q*P#PV8#_]VWZ,&C[][+LA4D+(P$B>43[]^+K`"A)T()+`FE[1%MH
MTO@8@`$K0=W?^/RA3_2`:=_X^+'`\B`)^D0`)?M$`20CX`%HVO@(`(MH4/@D
M<`GJ`P.S]8!O"+\):0K0,&@!DOOWA.P!F@(C$6@`(OOWA.L!1CA&^_<`ZP`H
M0/"1@-OX!#`!-`$UHT(-W3!H^_=N["I&`"-!1OOW+NP"1@`HT-%C2WM$6VA:
M'JI":=`P:/OW7NQ@20,C`2)Y1/OWCNL$1G"Q,&C[]U+L(VE;2AEH>D3[]T#K
M(VD;:)MH6P(`\8.`,&C[]T3L54D#(P$B>43[]W3K!$9XL5)(`IEX1/[W_/T%
M1C!H`"UCT/OW,.PC:2I&&6C[]R#K,&C[]RCL24U]1`1&,&C[]R+L1TD!(GE$
M^_=^ZT9*>D0!1B!&^_<,ZS!H^_<4[``B`ID#1D%(@_AE('A$_O?1_01&Z&!P
MLT_TX'$@1OOWC.M#'!$H&+\!*T38`YL%FAMHFD(]T0>PO>CPCP$KD]TS30$D
M?40P:`$T^_?NZT%&^_>:ZFMHHT+UW(7G+4M[1%MH6AZJ0G_T?Z_GYT-X`"L_
M]"6O(>>H:/_W`/L$1NA@`"C)T21(>$3[]T#K^_?,ZR)+(FE[1)MH$&@9:/[W
M8/^7YS!H^_?`ZR-I&6C[]U;K=.?[]X[J&DD#1AI((D9Y1'A$B6@):/OW(NL`
MOSA2`0`8`0``(`$``!H$``"R!0``D%,!`'13`0!P4P$`"E,!`!`%``#^!```
MZ`0``,8"``".4@$`K`0``+P$``!D`@``)%(!``I2`0`N!```U%$!`*I1`0`8
M!```.+4%1O_WWO@#>,.Q0AP$1B\K"+\41A+X`3L`*_C1__?U^0`M&+\`*`C0
M*W@SL0=)($9Y1/OWY.F$0@+0.+T$1NWG*$:]Z#A`_O=4OD8"```%2Q"T>T0%
M3!M9`[$;:%WX!$O[]R>Z`+\X3P$`,`$``"WI^$,'1@M.B$8+39%&?D3[]Z[I
M?41V&[80"=``)`$T5?@$.TI&048X1IA'ID+VT;WH^(/V30$`[$T!`'!'`+\(
M0"WI"("]Z`$``@!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(``````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````
M+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`
M````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/
M4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`````
M4$%27T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-
M4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.`````%!!4E]#3$5!3CT``#$```!365-414T``"4P,G@`````)7,E
M<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P87)L`````"YP87(`
M````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE
M=2TE=25S`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H``$%21U8`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)3
M24].`````#$N,#,V````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O
M<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%5315(`````
M55-%4DY!344`````5$5-4$1)4@!435``+W1M<`````!,1%],24)205)97U!!
M5$@`3$E"4$%42`!,24)205)97U!!5$@`````1%E,1%],24)205)97U!!5$@`
M``!32$Q)0E]0051(``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T
M<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`
M05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!
M4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92![
M"F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!
M4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E
M0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@
M)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN
M?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@
M*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P
M<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D
M9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO
M<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I
M.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E
M="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@
M)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L
M(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T[
M"FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;
M<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D
M(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB
M*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D
M;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL
M97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L
M("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD
M;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F
M+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?
M;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F
M=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL
M;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF
M7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI
M>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X
M="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L
M(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*
M)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I
M;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@
M>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X
M="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI]
M(&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M
M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N
M86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R
M8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@
M)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*
M8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@
M/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL
M97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@
M)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G
M9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[
M(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI
M"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A
M<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI
M9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@
M(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV
M("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M
M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]
M('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U
M<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^
M("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E
M<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*
M=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*
M)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S
M:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*
M?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q
M(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z
M($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@
M;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R
M)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@
M7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O
M<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@
M;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"([
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD
M9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@
M/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B
M7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%2
M7R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H
M("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE
M;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]
M('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*
M9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M"FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY
M("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@
M/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<
M6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS
M:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C
M:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ
M<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG
M+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D
M92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN
M="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*
M?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H
M95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C
M:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@
M>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO
M9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*
M)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G
M;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`
M(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI
M.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S
M<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@
M+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A
M=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL
M93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER
M95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*
M<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N
M:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD
M=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O
M;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@
M)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E
M860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F
M(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N
M86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T
M>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T
M('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H
M("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE
M(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M
M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*
M?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!2
M3T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD
M<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM0
M05)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI
M(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA
M;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B
M)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG
M>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF
M("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI]
M(&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#
M($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N
M)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]
M*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@
M)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H
M)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#
M3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@!<=_]_`0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#U&```M1@````````!`````0````$```#?`0``
M`0```"X"```!````B0,```P```#\$@``#0```,Q?```9````D*T!`!L````$
M````&@```)2M`0`<````!````/7^_V^T`0``!0```)`)```&````H`(```H`
M```%!0``"P```!`````5``````````,```"LK@$``@`````"```4````$0``
M`!<```#\$```$0```-0/```2````*`$``!,````(````&`````````#[__]O
M`0``"/[__V]T#P``____;P,```#P__]OE@X``/K__V\7````````````````
M`````````````````````````````````````````)RM`0````````````@3
M```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,`
M``@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``
M"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```(
M$P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3
M```($P``"!,```@3```($P``"!,```@3```($P``"!,```@3```($P``"!,`
M``@3```($P``"!,```@3```($P``"!,```@3``#)7P``````````````````
M```````````````````````````$L`$``````(U?````````*18`````````
M````````````````````!+`!`/____]$8P``5&,``%QC``!D8P``;&,``(!C
M````````/&,``&1@````````/&$``$!A```P8P``;&```#AC````````'&,`
M`"1C````````C&,``$=#0SH@*%5B=6YT=2],:6YA<F\@-BXS+C`M,G5B=6YT
M=3$I(#8N,RXP(#(P,38Q,C(Y`$=#0SH@*%5B=6YT=2],:6YA<F\@-BXR+C$M
M-75B=6YT=3(I(#8N,BXQ(#(P,38Q,C`R`$$R````865A8FD``2@````%-RU!
M``8*!T$(`0D""@02!!,!%`$5`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN
M=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA
M<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?
M<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A
M`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y
M`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN
M871T<FEB=71E<P``````````````````````````````````````````````
M``````````L````!`````@```%0!``!4`0``&0```````````````0``````
M```3````!P````(```!P`0``<`$``"````````````````0`````````(0``
M``<````"````D`$``)`!```D```````````````$`````````#0```#V__]O
M`@```+0!``"T`0``[`````4`````````!`````0````^````"P````(```"@
M`@``H`(``/`&```&`````P````0````0````1@````,````"````D`D``)`)
M```%!0`````````````!`````````$X```#___]O`@```)8.``"6#@``W@``
M``4``````````@````(```!;````_O__;P(```!T#P``=`\``&`````&````
M`P````0`````````:@````D````"````U`\``-0/```H`0``!0`````````$
M````"````',````)````0@```/P0``#\$`````(```4````6````!`````@`
M``!\`````0````8```#\$@``_!(```P```````````````0`````````=P``
M``$````&````"!,```@3```@`P`````````````$````!````((````!````
M!@```"@6```H%@``I$D`````````````"`````````"(`````0````8```#,
M7P``S%\```@```````````````0`````````C@````$````"````U%\``-1?
M``"T0``````````````$`````````)8````!``!P@@```(B@``"(H```"```
M``T`````````!`````````"A`````0````(```"0H```D*````0`````````
M``````0`````````JP````X````#````D*T!`)"M```$```````````````$
M````!````+<````/`````P```)2M`0"4K0``!```````````````!`````0`
M``##`````0````,```"8K0$`F*T```0```````````````0`````````R```
M``8````#````G*T!`)RM```0`0``!@`````````$````"````-$````!````
M`P```*RN`0"LK@``5`$`````````````!`````0```#6`````0````,`````
ML`$``+```%P```````````````0`````````W`````@````#````7+`!`%RP
M```8$``````````````$`````````.$````!````,`````````!<L```9@``
M`````````````0````$```#J`````P``<```````````PK```#,`````````
M``````$``````````0````,``````````````/6P``#Z```````````````!
'````````````
